*###########################################################################################
*### Relation of performance of the unit with performance of the subunit

*### PATHS (Put the file path where you downloaded the contents of the zip file)
*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
global path    ".../Example6/"
*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

*### VERSION TRACK
/*
Created by Pavel Luengas
Last update: Dec 1, 2022

Version 1.0 - Dec 1, 2022
   - File created 

Contact me for comments and questions:
pavel@pavellsierra.com */

*===========================================================================================

version 14
set more off

*#####################
*### ENDLINE
*#####################

use "$path/DatasetEndline.dta", clear

*============================================================================================================
*### TABLE - PANEL A

/* 
I use the code for the scatter plot as a template. So I finished the remaining three panels 
first. Crucially, the same components of panel D must be carried forward (ticks, titles, 
axis labels, etc). But I render all the components white. I also remove all borders (set 
their color to white) Using added text, I fill the information inside the chart/ 

Where to put the text and desc. stats? By trial and error, sadly.

Start with a line close to the top (Desc. Stats). Do not worry how the individual graph looks 
Check there how the combined graph looks. Based on the look, adjust the size and position 
of the text. Follow the same process in all four graphs. */

*====> MAKE GRAPH
*-------------------- Desc Stats ------
bysort unitid: gen first = (_n==1)
** Unit
sum indexunit_end if first==1
   local M_Unit : di %3.2f r(mean)
   local S_Unit : di %3.2f r(sd)
   local N_Unit : di %3.0f r(N) 
* Subunit
sum indexsubunit_end 
   local M_Subnit : di %3.2f r(mean)
   local S_Subnit : di %3.2f r(sd)
   local N_Subnit : di %3.0f r(N) 
*-------------------- Desc Stats ------

set scheme s1mono // Get rid of all color
twoway /*
   */ (scatter  indexunit_end indexsubunit_end,  msymbol(none )) /*
   */ (pci .78 .02 .78 .98, lcolor(black) lwidth(thin) ) /*

   */ , /*
   */ plotr(m(zero)) plotregion(lwidth(vthin) lcolor(white)) /* 
   */   /*
   */ ytitle(" ", size(medium))  /*
   */ yscale(range(0 1) lwidth(vthin) lcolor(white) ) /*
   */ ylabel(0.5 " ", labsize(medium) labcolor(white) ticks tlcolor(white) ) /*
   */   /*
   */ xtitle(" ", size(medium) )  /*
   */ xscale(range(0 1) lwidth(vthin) lcolor(white) alt) /*
   */ xlabel(0.5 " ", labsize(medium) labcolor(white) ticks tlcolor(white) ) /*
   */   /* 
   */   /* 
   */ text(.80 0.5  "Descriptive Statistics", placement(north) color(black) size(large)) /*   
   */ text(0.675 0.05 "Unit: ", placement(east) color(green) size(medlarge)) /*
   */ text(0.605 0.10 "{&mu}=`M_Unit', {&sigma}=`S_Unit', N=`N_Unit'", placement(east) color(black) size(medlarge)) /*
   */ text(0.475 0.05 "Subnit: ", placement(east) color(edkblue) size(medlarge)) /*
   */ text(0.405 0.10 "{&mu}=`M_Subnit', {&sigma}=`S_Subnit', N=`N_Subnit'", placement(east) color(black) size(medlarge)) /*
   */   /*  
   */ legend(off)

graph export "$path/Figs/PanelA_end.eps", replace 
graph save Graph "$path/GraphA_end.gph", replace
* MAKE GRAPH <==== 


*============================================================================================================
*### DENSITY OF PERFORMANCE OF THE UNIT - PANEL B

kdensity indexunit_end // Get the bandwidth (you could use a local to save it). Take note of the upper range of the density.
set scheme s1mono // Get rid of all color
twoway /*
   */ (kdensity indexunit_end, bw(0.06) lcolor(green) lwidth(medium)  ) /*
   */ , /*
   */ plotr(m(zero)) plotregion(lwidth(none) lcolor(white)) /* 
   */   /*
   */ ytitle("Density", size(medium)) /*
   */ yscale(range(0 3.0) lwidth(vthin) lcolor(white) alt) /*
   */ ylabel( 1.4 "1.4" 2.8 "2.8" , labsize(medium) labcolor(black) ticks tlcolor(white)) /*
   */   /*
   */ xtitle("Performance of Unit", size(medium) )  /*
   */ xscale(range(0 1) lwidth(vthin) lcolor(black) alt) /*
   */ xlabel(0 "0" .3 "0.30" .5 "0.50" .7 "0.70" 1 "1", labsize(medium)) /*
   */   /*
   */ xline(.3,  lwidth(thin) lcolor(edkblue) lpattern(dot)) /*
   */ xline(.5,  lwidth(thin) lcolor(edkblue) lpattern(dot)) /*
   */ xline(.7,  lwidth(thin) lcolor(edkblue) lpattern(dot)) /*
   */   /* 
   */ text(2.75 0.15  "D", placement(north) color(green) size(medium)) /*
   */ text(2.75 0.40  "C", placement(north) color(green) size(medium)) /*
   */ text(2.75 0.60  "B", placement(north) color(green) size(medium)) /*
   */ text(2.75 0.85  "A", placement(north) color(green) size(medium)) /*
   */   /*     
   */ legend(off)

graph export "$path/Figs/PanelB_end.eps", replace 
graph save Graph "$path/GraphB_end.gph", replace


*============================================================================================================
*### DENSITY OF PERFORMANCE OF THE SUBUNIT - PANEL C

kdensity indexsubunit_end // Get the bandwidth (you could use a local to save it). Take note of the upper range of the density.

set scheme s1mono // Get rid of all color
twoway /*
   */ (kdensity indexsubunit_end,  horiz bw(0.06) lcolor(edkblue) lwidth(medium)  ) /*
    */ , /*
   */ plotr(m(zero)) plotregion(lwidth(vthin) lcolor(white)) /* 
   */   /*
   */ ytitle("Performance of Subunit", size(medium)) /*
   */ yscale(range(0 1) lwidth(vthin) lcolor(black)) /*
   */ ylabel(0 "0" .3 "0.30" .5 "0.50" .7 "0.70" 1 "1", labsize(medium)) /*
   */ xtitle("Density", size(medium) )  /*
   */ xscale(range(0 2.3) lwidth(vthin) lcolor(white) reverse) /*
   */ xlabel(1.1 "1.1" 2.2 "2.2" , labsize(medium) labcolor(black) ticks tlcolor(white)) /*   
   */   /*
   */ yline(.3,  lwidth(thin) lcolor(edkblue) lpattern(dot)) /*
   */ yline(.5,  lwidth(thin) lcolor(edkblue) lpattern(dot)) /*
   */ yline(.7,  lwidth(thin) lcolor(edkblue) lpattern(dot)) /*
   */   /* 
   */ text(0.10 2.2   "D", placement(north) orient(vertical) color(edkblue) size(medium)) /*
   */ text(0.35 2.2   "C", placement(north) orient(vertical) color(edkblue) size(medium)) /*
   */ text(0.55 2.2   "B", placement(north) orient(vertical) color(edkblue) size(medium)) /*
   */ text(0.80 2.2   "A", placement(north) orient(vertical) color(edkblue) size(medium)) /*
   */   /*     
   */ legend(off)

graph export "$path/Figs/PanelC_end.eps", replace 
graph save Graph "$path/GraphC_end.gph", replace


*============================================================================================================
*### SCATTER PLOT - PANEL D

*## Local Linear Regression
lpoly  indexsubunit_end indexunit_end, degree(1)  noscatter ci // Take note of the bandwidth (you can save it as a local)

   *+++++++ Define grid [0-1, equally spaced] +++++++
   cap drop grid
   gen grid = (_n -1) /100 if _n<=101

   sum grid
   sum indexunit_end
   replace grid = . if grid<r(min)
   replace grid = . if grid>r(max)
   sum grid
   *+++++++ Define grid [0-1, equally spaced] +++++++

   * Local Linear Regression: Estimate at grid points, then save estimates and standard error
   lpoly indexsubunit_end indexunit_end, degree(1) bw(.1) noscatter ci at(grid) gen(y) se(se)
      gen y_lower = y - 1.96*se
      gen y_upper = y + 1.96*se

*====> MAKE GRAPH
*-------------------- Desc Stats ------
correl indexsubunit_end indexunit_end
   local rho : di %3.2f r(rho)

reg  indexsubunit_end indexunit_end, r
matrix B = e(b)

local alpha : di %3.2f `=B[1,2]'
local beta : di %3.2f `=B[1,1]'
local r2: di %3.2f e(r2)
*-------------------- Desc Stats ------

set scheme s1mono // Get rid of all color
** Thickness of the marker of the scatterplot
*  mlwidth(vvthin) --> Too thin
*  mlwidth(vthin) --> Too thick
*  mlwidth(*.05) --> Play with a width that looks good. For some reason, Latex does not respect the width recorded in the eps file. A JPG (maybe a PDF too?) will do.
twoway /*
   */ (scatter indexsubunit_end indexunit_end,   mlwidth(*0.05) msize(vsmall) mfcolor(none)  mlcolor(black)  ) /*
   */ (lfit indexsubunit_end indexunit_end, lpattern(dash) lcolor(cranberry) lwidth(thin)) /*
   */ (line y grid,         lpattern(solid) lcolor(dknavy)  lwidth(vthin)  )  /*
   */ (line y_lower grid,   lcolor(dknavy) lpattern(solid) lwidth(medium)  )  /*
   */ (line y_upper grid,   lcolor(dknavy) lpattern(solid) lwidth(medium)  )  /*
   */ , /*
   */ plotr(m(zero)) plotregion(lwidth(vthin) lcolor(black)) /* 
   */   /*
   */ ytitle("Performance of Subunit", size(medium)) /*
   */ yscale(range(0 1) lwidth(vthin) lcolor(black) alt) /*
   */ ylabel(0 "0" .3 "0.30" .5 "0.50" .7 "0.70" 1 "1", labsize(medium)  ) /*
   */   /*
   */ xtitle("Performance of Unit", size(medium) )  /*
   */ xscale(range(0 1) lwidth(vthin) lcolor(black)) /*
   */ xlabel(0 "0" .3 "0.30" .5 "0.50" .7 "0.70" 1 "1", labsize(medium)) /*
   */   /*
   */ xline(.3,  lwidth(thin) lcolor(edkblue) lpattern(dot)) /*
   */ xline(.5,  lwidth(thin) lcolor(edkblue) lpattern(dot)) /*
   */ xline(.7,  lwidth(thin) lcolor(edkblue) lpattern(dot)) /*
   */   /*
   */ yline(.3,  lwidth(thin) lcolor(edkblue) lpattern(dot)) /*
   */ yline(.5,  lwidth(thin) lcolor(edkblue) lpattern(dot)) /*
   */ yline(.7,  lwidth(thin) lcolor(edkblue) lpattern(dot)) /*
   */   /* 
   */ text(0.180 0.02 "Linear fit: ", placement(east) color(cranberry) size(small)) /*
   */ text(0.120 0.02 "{&alpha}=`alpha', {&beta}=`beta', r{superscript:2}=`r2'", placement(east) color(cranberry) size(small)) /*
   */ text(0.060 0.02 "{&rho}=`rho'", placement(east) color(cranberry) size(small)) /*
   */   /*  
   */ text(0.820 0.17 "LLR", placement(west) color(dknavy) size(medsmall)) /*
   */ text(`alpha' 0.17 "LFit", placement(west) color(cranberry) size(medsmall)) /*
   */ legend(off)

graph export "$path/Figs/PanelD_end.eps", replace 
graph save Graph "$path/GraphD_end.gph", replace
* MAKE GRAPH <==== 


*================================================================================================================
*================================================================================================================
*================================================================================================================
*================================================================================================================

cd "$path"
graph combine GraphA_end.gph GraphB_end.gph GraphC_end.gph GraphD_end.gph, /*
   */ imargin(0 0 0 0) /*
   */ graphregion(margin(l=22 r=22)) /*
   */ note("LLR: Local Linear Regression. Kernel=Epanechnikov. Bandwidth=0.10", size(small))

graph export "$path/Figs/Endline.eps", replace 
graph save Graph "$path/Endline.gph", replace
* MAKE GRAPH <==== 

